@@ -43,10 +43,7 @@ class SoftDeleteModelMixin(models.Model):
 
     def delete(self, using=None, keep_parents=False):
         if not self.is_deleted:
-            signals.pre_soft_delete.send(
-                sender=self.__class__,
-                instance=self,
-            )
+            signals.pre_soft_delete.send(sender=self.__class__, instance=self)
 
             # save & skip signals
             self.deleted_at = now()
@@ -55,10 +52,38 @@ class SoftDeleteModelMixin(models.Model):
             with UnplugSignal(signal=pre_save, func=verify_soft_deletion, model=self.__class__):
                 self.save()
 
-            signals.post_soft_delete.send(
-                sender=self.__class__,
-                instance=self,
-            )
+            signals.post_soft_delete.send(sender=self.__class__, instance=self)
+
+            # Delete related
+            all_related = [
+                f
+                for f in self._meta.get_fields()
+                if (f.one_to_many or f.one_to_one) and f.auto_created and not f.concrete
+            ]
+
+            for related in all_related:
+                on_delete = related.on_delete.__name__
+                if on_delete not in ("CASCADE", "SET_NULL"):
+                    continue
+
+                relation_field = related.get_accessor_name()
+                try:
+                    value = getattr(self, relation_field)
+                except related.related_model.DoesNotExist:
+                    continue
+
+                match related.one_to_one, on_delete,:
+                    case True, "CASCADE":
+                        value.delete()
+                    case True, "SET_NULL":
+                        setattr(value, related.field.name, None)
+                        value.save()
+                    case False, "CASCADE":
+                        value.all().delete()
+                    case False, "SET_NULL":
+                        value.update(**{related.field.name: None})
+        else:
+            super().delete(using=using, keep_parents=keep_parents)
 
     def undelete(self):
         if self.is_deleted:
